#!/usr/bin/perl -w
use strict;
use ExtUtils::MakeMaker;
use File::Spec;
use CTK;
use CTK::Util qw/sharedstatedir sharedir/;

use constant {
        PROJECT_NAME  => "NoRFC",
        PROJECT_NAMEL => "norfc",
    };

my $build_requires = {
        'CTK'                   => 2.03,
        'ExtUtils::MakeMaker'   => 6.60,
        'Test::More'            => 0.94,
    };

my $prereq_pm = {
        'Compress::Zlib'        => 2.00, # perl-IO-Compress
        'CTK'                   => 2.03, # perl-CTK
        'Encode::Locale'        => 1.00, # perl-Encode-Locale
        'YAML::LibYAML'         => 0.18, # perl-YAML-LibYAML
        'File::HomeDir'         => 1.00, # perl-File-HomeDir
        'GnuPG::Interface'      => 0.52, # perl-GnuPG-Interface (libgnupg-interface-perl)
        'DBD::SQLite'           => 1.00, # perl-DBD-SQLite (libdbd-sqlite3-perl)
        'MIME::Base64'          => 3.00,
        'Mojolicious'           => 7.94, # perl-Mojolicious (libmojolicious-perl)
        'Text::Tabs'            => 0,
    };

my $exefiles = [qw(
        bin/norfc
    )];

my $ctk = new CTK( project => PROJECT_NAME );
WriteMakefile(
    'NAME'              => PROJECT_NAME,
    'DISTNAME'          => PROJECT_NAMEL,
    'MIN_PERL_VERSION'  => 5.016001,
    'VERSION_FROM'      => 'lib/NoRFC.pm',
    'ABSTRACT_FROM'     => 'lib/NoRFC.pm',
    'BUILD_REQUIRES'    => $build_requires,
    'PREREQ_PM'         => $prereq_pm,
    'EXE_FILES'         => $exefiles,
    'AUTHOR'            => 'Serz Minus (Sergey Lepenkov) <minus@serzik.com>',
    'LICENSE'           => 'GPL',
    'META_MERGE'        => {
        resources => {
            homepage        => 'https://www.serzik.com',
            repository      => 'https://git.mns.suffit.org/minus/norfc.git',
            license         => 'http://opensource.org/licenses/gpl-license.php',
        },
    },
    macro => {
            PROJECT_NAME    => PROJECT_NAME,
            PROJECT_NAMEL   => PROJECT_NAMEL,
            PROJECT_CONFDIR => '$(DESTDIR)' . $ctk->root,
            PROJECT_DATADIR => '$(DESTDIR)' . File::Spec->catdir(sharedstatedir(), PROJECT_NAMEL),
            PROJECT_SHAREDIR => '$(DESTDIR)' . File::Spec->catdir(sharedir(), PROJECT_NAMEL),
        },
    clean => {
            FILES => '$(INST_CONF) *.tmp norfc.db',
        },
);

1;

package MY;
use CTK::Util qw/dformat/;

sub postamble {
my $section = <<'MAKE_FRAG';
INST_CONF = blib$(DFSEP)conf
INST_SHARE = blib$(DFSEP)share

CRLF = $(ABSPERLRUNINST) -MCTK::Command -e crlf --

pure_all :: configured.tmp
[TAB]$(NOECHO) $(ECHO) "Configured."

# Configure
configured.tmp : conf$(DFSEP)$(PROJECT_NAMEL).conf $(INST_CONF)$(DFSEP).exists $(INST_SHARE)$(DFSEP).exists
[TAB]$(CP) conf$(DFSEP)$(PROJECT_NAMEL).conf $(INST_CONF)
[TAB]$(CRLF) $(INST_CONF)
[TAB]$(CP) conf$(DFSEP)conf.d$(DFSEP)README $(INST_CONF)$(DFSEP)conf.d
[TAB]$(CP) src$(DFSEP)certs$(DFSEP)* $(INST_CONF)$(DFSEP)certs$(DFSEP)
[TAB]$(CP) src$(DFSEP)www$(DFSEP)* $(INST_SHARE)$(DFSEP)
[TAB]$(NOECHO) $(TOUCH) configured.tmp

# Creating directories
$(INST_CONF)$(DFSEP).exists :: Makefile.PL
[TAB]$(MKPATH) $(INST_CONF)$(DFSEP)conf.d
[TAB]$(MKPATH) $(INST_CONF)$(DFSEP)certs
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(INST_CONF)
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(INST_CONF)$(DFSEP)conf.d
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(INST_CONF)$(DFSEP)certs
[TAB]$(NOECHO) $(TOUCH) $(INST_CONF)$(DFSEP).exists

$(INST_SHARE)$(DFSEP).exists :: Makefile.PL
[TAB]$(MKPATH) $(INST_SHARE)
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(INST_SHARE)
[TAB]$(NOECHO) $(TOUCH) $(INST_SHARE)$(DFSEP).exists

install :: installed.tmp
[TAB]$(NOECHO) $(ECHO) The $(PROJECT_NAME) project has been successfully installed.

installed.tmp : configured.tmp
[TAB]$(MKPATH) $(PROJECT_CONFDIR)$(DFSEP)conf.d
[TAB]$(MKPATH) $(PROJECT_CONFDIR)$(DFSEP)certs
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(PROJECT_CONFDIR)
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(PROJECT_CONFDIR)$(DFSEP)conf.d
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(PROJECT_CONFDIR)$(DFSEP)certs
[TAB]$(TEST_F) $(PROJECT_CONFDIR)$(DFSEP)$(PROJECT_NAMEL).conf && $(CP) $(INST_CONF)$(DFSEP)$(PROJECT_NAMEL).conf $(PROJECT_CONFDIR)$(DFSEP)$(PROJECT_NAMEL).conf.orig || $(CP) $(INST_CONF)$(DFSEP)$(PROJECT_NAMEL).conf $(PROJECT_CONFDIR)$(DFSEP)$(PROJECT_NAMEL).conf
[TAB]$(CP) $(INST_CONF)$(DFSEP)conf.d$(DFSEP)README $(PROJECT_CONFDIR)$(DFSEP)conf.d$(DFSEP)README
[TAB]$(CP) $(INST_CONF)$(DFSEP)certs$(DFSEP)* $(PROJECT_CONFDIR)$(DFSEP)certs$(DFSEP)
[TAB]$(MKPATH) $(PROJECT_DATADIR)
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(PROJECT_DATADIR)
[TAB]$(MKPATH) $(PROJECT_SHAREDIR)
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(PROJECT_SHAREDIR)
[TAB]$(CP) $(INST_SHARE)$(DFSEP)* $(PROJECT_SHAREDIR)
[TAB]$(NOECHO) $(TOUCH) installed.tmp
MAKE_FRAG

return dformat($section, {
        TAB => "\t",
    });
}

1;

__END__
