#!/usr/bin/perl -w
#########################################################################
#
# Serz Minus (Sergey Lepenkov), <abalama@cpan.org>
#
# Copyright (C) 1998-2021 D&D Corporation. All Rights Reserved
#
# This is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.
#
# $Id: 04-gnupg.t 183 2021-03-04 16:58:01Z minus $
#
#########################################################################
use Test::More;
use File::Spec;
use File::Temp qw/ tempfile tempdir /;
use CTK::ConfGenUtil;
use NoRFC;

my $app = NoRFC->new(
        project => NoRFC::PROJECTNAME,
        configfile => File::Spec->catfile("conf", sprintf("%s.conf", NoRFC::PROJECTNAMEL)),
        datadir => tempdir(CLEANUP => 1),
    );
unless ($app->status) {
    diag($app->error || "unknown error");
    plan skip_all => "Can't init application";
}

my $fingerprint = value($app->conf("fingerprint"));
plan skip_all => "This test requires the Fingerprint directive of the configuration file" unless $fingerprint;

plan tests => 4;


# Test fingerprint
ok(NoRFC::_fingerprint_test($fingerprint), "Fingerprint test") and note("Fingerprint: " . $fingerprint);

# Get author
my %users = $app->private_keys_info();
my $author = $users{$fingerprint};
ok($author, "Author define") and note(explain($author));

# Sign
my $sign = $app->sign($fingerprint => "Test") || "Incorrect signature";
ok($sign, "Signature status") or note($app->error);

# Check signature format
ok($sign =~ /^\-\-\-\-\-BEGIN\sPGP.+\-\-\-\-\-END\sPGP/s, "Signature format") or note($sign);

1;

__END__

prove -lv t/04-gnupg.t
